**Devlog guidelines:**
- All new code needs to be tested and documented. Add daily tasks accordingly.
- The written dissertation (or at least the notes to write it) needs to move along with all the other goals.

# Daily sprint goals

- finish work on existing classes and add a new one
- make a colab demo of the new code
- rewrite outdated documents (new goal = 100% colab)

# Tasks for the day

- [ ] update docs
	- [ ] components diagram
	- [ ] sequence diagram
	- [ ] use cases
	- [ ] project plan
	- [ ] requirements spec
- [ ] add tests to existing classes
	- [x] lldf
	- [x] pca
	- [x] lda
	- [ ] svm
- [ ] implement new class: kNN (the simplest from the remaining)
- [ ] write a piece of written dissertation

# Notes

- 

# Shutdown and Retrospective

- [x] test and validate all new code
- [x] commit to the remote repo
- [x] make a schedule for tomorrow

**Did anything go wrong? What could have been done better, and how?**
- the code did not pass validation: it can't predict anything on new data. I need to make a synthetic dataset from the data I have.
- the prediction system can be extracted from a piece of the training function
- SVM needs tests
- I need a remote document builder